@@ -107,6 +107,8 @@ def leagueStatSheet(league: League, **kwargs) -> AllTimeStatSheet:
 
 
 def yearStatSheet(year: Year, **kwargs) -> YearStatSheet:
+    ownerNames = kwargs.pop("ownerNames", None)
+    years = kwargs.pop("years", None)
     # Team Summary
     gamesPlayed = TeamSummaryYearCalculator.getGamesPlayed(year, **kwargs)
     # Game Outcome
@@ -177,4 +179,4 @@ def yearStatSheet(year: Year, **kwargs) -> YearStatSheet:
                          teamScore=teamScore, teamSuccess=teamSuccess, teamLuck=teamLuck,
                          leagueMedianWins=leagueMedianWins, totalGames=totalGames,
                          opponentLeagueMedianWins=opponentLeagueMedianWins, maxScoringShare=maxScoringShare,
-                         minScoringShare=minScoringShare)
+                         minScoringShare=minScoringShare, ownerNames=ownerNames, years=years)
